# dspls
This is a Partial Least Squares (PLS) package based on Python.

Partial least squares (PLS) is an extension of PCA in which both the  X and Y data are considered. In PCA, only the X data is considered. The goal of the PLS analysis is to build an equation that predicts Y values based on X data.

# Update
0.0.1 Finish the code of Basic PLS

0.0.2 Update the KernelPLS


# Download
The requirements are listed in "requirements.txt"

Use "pip install git+https://github.com/achrafs758/PLS-from-scratch.git" to install.


